@@ -222,16 +222,6 @@ typedef struct {
     void	(*PreInit)(ScrnInfoPtr);
 } MGARamdacRec, *MGARamdacPtr;
 
-
-typedef struct {
-    int bitsPerPixel;
-    int depth;
-    int displayWidth;
-    rgb weight;
-    Bool Overlay8Plus24;
-    DisplayModePtr mode;
-} MGAFBLayout;
-
 /* Card-specific driver information */
 
 typedef struct {
@@ -463,10 +453,6 @@ typedef struct {
     int			StyleLen;
     XAAInfoRecPtr	AccelInfoRec;
     xf86CursorInfoPtr	CursorInfoRec;
-    DGAModePtr		DGAModes;
-    int			numDGAModes;
-    Bool		DGAactive;
-    int			DGAViewportStatus;
     CARD32		*Atype;
     CARD32		*AtypeNoBLK;
     void		(*PreInit)(ScrnInfoPtr pScrn);
@@ -488,7 +474,6 @@ typedef struct {
     int			videoKey;
     int			fifoCount;
     int			Rotate;
-    MGAFBLayout		CurrentLayout;
     Bool		DrawTransparent;
     int			MaxBlitDWORDS;
     Bool		TexturedVideo;
@@ -611,8 +596,6 @@ Bool MGAHWCursorInit(ScreenPtr pScreen);
 
 void MGAPolyArcThinSolid(DrawablePtr, GCPtr, int, xArc*);
 
-Bool MGADGAInit(ScreenPtr pScreen);
-
 void MGARefreshArea(ScrnInfoPtr pScrn, int num, BoxPtr pbox);
 void MGARefreshArea8(ScrnInfoPtr pScrn, int num, BoxPtr pbox);
 void MGARefreshArea16(ScrnInfoPtr pScrn, int num, BoxPtr pbox);
