@@ -3,6 +3,20 @@
 #ifndef _MGA_MACROS_H_
 #define _MGA_MACROS_H_
 
+#ifdef XSERVER_LIBPCIACCESS
+#define MGA_IO_ADDRESS(p) (p)->PciInfo->regions[(p)->io_bar].base_addr
+#define VENDOR_ID(p)      (p)->vendor_id
+#define DEVICE_ID(p)      (p)->device_id
+#define SUBSYS_ID(p)      (p)->subdevice_id
+#define CHIP_REVISION(p)  (p)->revision
+#else
+#define MGA_IO_ADDRESS(p) (p)->IOAddress
+#define VENDOR_ID(p)      (p)->vendor
+#define DEVICE_ID(p)      (p)->chipType
+#define SUBSYS_ID(p)      (p)->subsysCard
+#define CHIP_REVISION(p)  (p)->chipRev
+#endif
+
 #define RGBEQUAL(c) (!((((c) >> 8) ^ (c)) & 0xffff))
 
 #ifdef XF86DRI
@@ -27,7 +41,7 @@ while(INREG(MGAREG_DWGSYNC) != MGA_SYNC_XTAG) ; \
    }
 
 #define XYADDRESS(x,y) \
-    ((y) * pMga->CurrentLayout.displayWidth + (x) + pMga->YDstOrg)
+    ((y) * pScrn->displayWidth + (x) + pMga->YDstOrg)
 
 #define MAKEDMAINDEX(index)  ((((index) >> 2) & 0x7f) | (((index) >> 6) & 0x80))
 
@@ -62,24 +76,6 @@ while(INREG(MGAREG_DWGSYNC) != MGA_SYNC_XTAG) ; \
 #define CHECK_DMA_QUIESCENT(pMGA, pScrn)
 #endif
 
-#ifdef USEMGAHAL
-#define HAL_CHIPSETS (pMga->is_HAL_chipset)
-    
-#define MGA_HAL(x) { \
-	MGAPtr pMga = MGAPTR(pScrn); \
-	if (pMga->HALLoaded && HAL_CHIPSETS) { x; } \
-}
-#define MGA_NOT_HAL(x) { \
-	MGAPtr pMga = MGAPTR(pScrn); \
-	if (!pMga->HALLoaded || !HAL_CHIPSETS) { x; } \
-}
-#else
-#define MGA_NOT_HAL(x) { x; }
-#endif
-
 #define MGAISGx50(x) ((x)->is_Gx50)
 
-#define MGA_DH_NEEDS_HAL(x) (((x)->Chipset == PCI_CHIP_MGAG400) && \
-			     ((x)->ChipRev < 0x80))
-
 #endif /* _MGA_MACROS_H_ */
