@@ -219,10 +219,11 @@
 
 #define MGADWG_PATTERN		( 0x01 << 29 )
 #define MGADWG_TRANSC		( 0x01 << 30 )
+
 #define MGAREG_MISC_WRITE	0x3c2
 #define MGAREG_MISC_READ	0x3cc
-#define MGAREG_MEM_MISC_WRITE       0x1fc2
-#define MGAREG_MEM_MISC_READ        0x1fcc
+#define MGAREG_MISC_HSYNCPOL    0x40
+#define MGAREG_MISC_VSYNCPOL    0x80
 
 #define MGAREG_MISC_IOADSEL	(0x1 << 0)
 #define MGAREG_MISC_RAMMAPEN	(0x1 << 1)
@@ -236,10 +237,15 @@
 /* MMIO VGA registers */
 #define MGAREG_SEQ_INDEX	0x1fc4
 #define MGAREG_SEQ_DATA		0x1fc5
+#define MGAREG_SEQ1_SCREEN_OFF 0x20
+
 #define MGAREG_CRTC_INDEX	0x1fd4
 #define MGAREG_CRTC_DATA	0x1fd5
+
 #define MGAREG_CRTCEXT_INDEX	0x1fde
 #define MGAREG_CRTCEXT_DATA	0x1fdf
+#define MGAREG_CRTCEXT1_HSYNC_OFF 0x10
+#define MGAREG_CRTCEXT1_VSYNC_OFF 0x20
 
 
 
@@ -319,7 +325,6 @@
 
 #define MGA1064_INDEX		0x00
 #define MGA1064_WADR_PAL	0x00
-#define MGA1064_SPAREREG        0x00
 #define MGA1064_COL_PAL		0x01
 #define MGA1064_PIX_RD_MSK	0x02
 #define MGA1064_RADR_PAL	0x03
@@ -383,16 +388,6 @@
 #define MGA1064_SYS_PLL_N	0x2d
 #define MGA1064_SYS_PLL_P	0x2e
 #define MGA1064_SYS_PLL_STAT	0x2f
-
-#define MGA1064_REMHEADCTL     0x30
-#define MGA1064_REMHEADCTL_CLKDIS ( 0x01 << 0 )
-#define MGA1064_REMHEADCTL_CLKSL_OFF ( 0x00 << 1 )
-#define MGA1064_REMHEADCTL_CLKSL_PLL ( 0x01 << 1 )
-#define MGA1064_REMHEADCTL_CLKSL_PCI ( 0x02 << 1 )
-#define MGA1064_REMHEADCTL_CLKSL_MSK ( 0x03 << 1 )
-
-#define MGA1064_REMHEADCTL2     0x31
-
 #define MGA1064_ZOOM_CTL	0x38
 #define MGA1064_SENSE_TST	0x3a
 
@@ -422,22 +417,6 @@
 #define MGA1064_VID_PLL_M       0x8E
 #define MGA1064_VID_PLL_N       0x8F
 
-/* Modified PLL for G200 Winbond (G200WB) */
-#define MGA1064_WB_PIX_PLLC_M	0xb7
-#define MGA1064_WB_PIX_PLLC_N	0xb6
-#define MGA1064_WB_PIX_PLLC_P	0xb8
-
-/* Modified PLL for G200 Maxim (G200EV) */
-#define MGA1064_EV_PIX_PLLC_M	0xb6
-#define MGA1064_EV_PIX_PLLC_N	0xb7
-#define MGA1064_EV_PIX_PLLC_P	0xb8
-
-/* Modified PLL for G200 EH */
-#define MGA1064_EH_PIX_PLLC_M   0xb6
-#define MGA1064_EH_PIX_PLLC_N   0xb7
-#define MGA1064_EH_PIX_PLLC_P   0xb8
-
-
 #define MGA1064_DISP_CTL        0x8a
 #define MGA1064_DISP_CTL_DAC1OUTSEL_MASK       0x01
 #define MGA1064_DISP_CTL_DAC1OUTSEL_DIS        0x00
@@ -464,17 +443,6 @@
 
 #define MGA1064_PAN_CTL         0xa2
 
-/* Using crtc2 */
-#define MGAREG2_C2CTL            0x10
-#define MGAREG2_C2HPARAM         0x14
-#define MGAREG2_C2HSYNC          0x18
-#define MGAREG2_C2VPARAM         0x1c
-#define MGAREG2_C2VSYNC          0x20
-#define MGAREG2_C2STARTADD0      0x28
-
-#define MGAREG2_C2OFFSET         0x40
-#define MGAREG2_C2DATACTL        0x4c
-
 #define MGAREG_C2CTL            0x3c10
 #define MGAREG_C2CTL_C2_EN                     0x01
 
